function results=TEntropy(mhx,mhy,mhz,mhxy,mhxz,mhxyz)
% PURPOSE: Compute total entropy
%---------------------------------------------------
% USAGE:     results = TEntropy(mhx,mhy,mhz,mhxy,mhxz,mhxyz)
% where inputs are output from symbols(x,y,z) and
% x = data, dependent at t
%        y = data, dependent at t-1
%        z = data, independent       
%---------------------------------------------------
% RETURNS:
%    results = a structure with entropy of
%              x, y, z, xy, xz and xyz
%---------------------------------------------------
% COMMENTS: For joint use with symbols(x,y,z)
%
% written by:
% Manuel Ruiz-Marin
% Universidad Politecnica de Cartagena
  n=length(mhx);
  [lsymx,rx,sx]=unique(mhx,'rows');
  [lsymy,ry,sy]=unique(mhy,'rows');
  [lsymz,rz,sz]=unique(mhz,'rows');
  [lsymxy,rxy,sxy]=unique(mhxy,'rows');
  [lsymxz,rxz,sxz]=unique(mhxz,'rows');
  [lsymxyz,rxyz,sxyz]=unique(mhxyz,'rows');
 
  nsx=hist(sx,1:length(lsymx))/n;
  nsy=hist(sy,1:length(lsymy))/n;
  nsz=hist(sz,1:length(lsymz))/n;
  nsxy=hist(sxy,1:length(lsymxy))/n;
  nsxz=hist(sxz,1:length(lsymxz))/n;
  nsxyz=hist(sxyz,1:length(lsymxyz))/n;
   
  lognsx=log(nsx);
  lognsy=log(nsy);
  lognsz=log(nsz);
  lognsxy=log(nsxy);
  lognsxz=log(nsxz);
  lognsxyz=log(nsxyz);
    
  entx=-sum(nsx.*lognsx);
  enty=-sum(nsy.*lognsy);
  entz=-sum(nsz.*lognsz);
  entxy=-sum(nsxy.*lognsxy);
  entxz=-sum(nsxz.*lognsxz);
  entxyz=-sum(nsxyz.*lognsxyz);
    
  entycondx=entxy-entx;
  entycondxz=entxyz-entxz;
    
  results.entx=entx;
  results.enty=enty;
  results.entz=entz;
  results.entxy=entxy;
  results.entxz=entxz;
  results.entxyz=entxyz;   
  results.TE=entycondx-entycondxz;
   
end
