function results=symbols(x,y,z,m)
% PURPOSE: Convert original data to symbols
%---------------------------------------------------
% USAGE:     results = symbols(x,y,z,m)
% where: x = data, dependent at t
%        y = data, dependent at t-1
%        z = data, independent       
%---------------------------------------------------
% RETURNS:
%    results = a structure with sorted indices of
%              x, y, z, xy, xz and xyz
%---------------------------------------------------
% COMMENTS: For joint use with TEntropy
%
% written by:
% Manuel Ruiz-Marin
% Universidad Politecnica de Cartagena

  T=length(x);
  n=T-m+1;

  mhx=zeros(n,m);
  mhy=zeros(n,m);
  mhz=zeros(n,m);
  mhxy=zeros(n,2*m);
  mhxz=zeros(n,2*m);
  mhxyz=zeros(n,3*m);
  for i=1:T-m+1;
    [Bx,mhx(i,:)]=sort(x(i:i+m-1)');
    [By,mhy(i,:)]=sort(y(i:i+m-1)');
    [Bz,mhz(i,:)]=sort(z(i:i+m-1)');
    mhxy(i,:)=[mhx(i,:) mhy(i,:)];
    mhxz(i,:)=[mhx(i,:) mhz(i,:)];
    mhxyz(i,:)=[mhx(i,:) mhy(i,:) mhz(i,:)];
  end;

  results.mhx=mhx;  
  results.mhy=mhy;
  results.mhz=mhz;
  results.mhxy=mhxy;
  results.mhxz=mhxz;
  results.mhxyz=mhxyz;

end
